@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::Controller;
 BEGIN {
-  $Games::Risk::Controller::VERSION = '3.101390';
+  $Games::Risk::Controller::VERSION = '3.101430';
 }
 # ABSTRACT: controller poe session for risk
 
@@ -227,7 +227,7 @@ sub _onpub_attack_move {
 
     # update the gui
     $h->send_to_all('chnum', $src);
-    $h->send_to_all('chown', $dst);
+    $h->send_to_all('chown', $dst, $looser);
 
     # check if previous $dst owner has lost.
     if ( scalar($looser->countries) == 0 ) {
@@ -754,7 +754,7 @@ Games::Risk::Controller - controller poe session for risk
 
 =head1 VERSION
 
-version 3.101390
+version 3.101430
 
 =head1 SYNOPSIS
 
